@@ -89,7 +89,7 @@ class Layer(Widget, InteractMixin):
     popup_max_width = Int(300).tag(sync=True)
     popup_max_height = Int(default_value=None, allow_none=True).tag(sync=True)
 
-    options = List(trait=Unicode).tag(sync=True)
+    options = List(trait=Unicode()).tag(sync=True)
 
     def __init__(self, **kwargs):
         super(Layer, self).__init__(**kwargs)
@@ -239,6 +239,7 @@ class TileLayer(RasterLayer):
     attribution = Unicode('Map data (c) <a href="https://openstreetmap.org">OpenStreetMap</a> contributors').tag(sync=True, o=True)
     detect_retina = Bool(False).tag(sync=True, o=True)
     no_wrap = Bool(False).tag(sync=True, o=True)
+    tms = Bool(False).tag(sync=True, o=True)
 
     _load_callbacks = Instance(CallbackDispatcher, ())
 
@@ -312,7 +313,7 @@ class Velocity(Layer):
     longitude_dimension = Unicode('longitude', help='Name of the longitude dimension in the dataset')
     units = Unicode(None, allow_none=True)
 
-    data = Dataset().tag(sync=True, to_json=ds_x_to_json)
+    data = Dataset().tag(dtype=None, sync=True, to_json=ds_x_to_json)
 
     # Options
     display_values = Bool(True).tag(sync=True, o=True)
@@ -431,7 +432,7 @@ class MarkerCluster(Layer):
     _view_name = Unicode('LeafletMarkerClusterView').tag(sync=True)
     _model_name = Unicode('LeafletMarkerClusterModel').tag(sync=True)
 
-    markers = Tuple(trait=Instance(Marker)).tag(sync=True, **widget_serialization)
+    markers = Tuple().tag(trait=Instance(Marker), sync=True, **widget_serialization)
 
 
 class LayerGroup(Layer):
@@ -584,7 +585,7 @@ class Control(Widget):
     _view_module_version = Unicode(EXTENSION_VERSION).tag(sync=True)
     _model_module_version = Unicode(EXTENSION_VERSION).tag(sync=True)
 
-    options = List(trait=Unicode).tag(sync=True)
+    options = List(trait=Unicode()).tag(sync=True)
 
     position = Enum(
         ['topright', 'topleft', 'bottomright', 'bottomleft'],
@@ -855,7 +856,7 @@ class Map(DOMWidget, InteractMixin):
     # marker_zoom_animation = Bool(?).tag(sync=True, o=True)
     fullscreen = Bool(False).tag(sync=True, o=True)
 
-    options = List(trait=Unicode).tag(sync=True)
+    options = List(trait=Unicode()).tag(sync=True)
 
     style = InstanceDict(MapStyle).tag(sync=True, **widget_serialization)
     default_style = InstanceDict(MapStyle).tag(sync=True, **widget_serialization)
